/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JDBCDatasource.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.configuration;

import org.ow2.jonas.tools.configurator.api.JDBCConfiguration;

/**
 * Create a new JDBCDatasource object.
 * @author skabore
 */
public class JDBCDatasource {

    /**
     * The datasource name.
     */
    private String datasourceName;

    /**
     * The ra name.
     */
    private String raName;

    /**
     * The dbms name.
     */
    private String dbmsName;

    /**
     * The list JDBCConfiguration.
     */
    private JDBCConfiguration jdbcConfiguration;

    /**
     * Default constructor.
     */
    public JDBCDatasource() {
        jdbcConfiguration = new JDBCConfiguration();
    }

    /**
     * @return datasourceName.
     */
    public String getDatasourceName() {
        return datasourceName;
    }

    /**
     * Set the datasourceName value.
     * @param datasourceName the new value
     */
    public void setDatasourceName(final String datasourceName) {
        this.datasourceName = datasourceName;
    }

    /**
     * @return the jdbcConfiguration
     */
    public JDBCConfiguration getJdbcConfiguration() {
        return jdbcConfiguration;
    }

    /**
     * Set the jdbcConfiguration value.
     * @param jdbcConfiguration new value
     */
    public void setJdbcConfiguration(final JDBCConfiguration jdbcConfiguration) {
        this.jdbcConfiguration = jdbcConfiguration;
    }

    /**
     * @return the dbms name.
     */
    public String getDbmsName() {
        return dbmsName;
    }

    /**
     * Set the dbms name.
     * @param dbmsName the dbms name new value
     */
    public void setDbmsName(final String dbmsName) {
        this.dbmsName = dbmsName;
    }

    /**
     * @return raName.
     */
    public String getRaName() {
        return raName;
    }

    /**
     * Set the ra name.
     * @param raName the ra name new value
     */
    public void setRaName(final String raName) {
        this.raName = raName;
    }

    /**
     * Initialize JdbcConfiguration by the default value.
     */
    @SuppressWarnings("empty-statement")
    public void initializeJdbcConfiguration() {
        String driver = "";
        jdbcConfiguration.datasourceClass = driver;
        jdbcConfiguration.driverName = "org.hsqldb.jdbcDriver";
        jdbcConfiguration.jndiName = "jdbc_1";
        jdbcConfiguration.mappername = "rdb.hsql";
        jdbcConfiguration.password = "jonas";
        jdbcConfiguration.url = "jdbc:hsqldb:hsql://localhost:9001/db_jonas";
        jdbcConfiguration.user = "jonas";
        jdbcConfiguration.rarLink = "NoLink";
        initializeJdbcConfigurationAdvancedParameters();
    }

    /**
     * Initialize JdbcConfiguration advanced parameters by the default value.
     */
    public void initializeJdbcConfigurationAdvancedParameters() {
        jdbcConfiguration.checkLevel = "1";
        jdbcConfiguration.poolInitialSize = "1";
        jdbcConfiguration.poolMaximumAgeMinutes = "1440";
        jdbcConfiguration.poolMaximumNumberOfPreparedStatements = "60";
        jdbcConfiguration.poolMaximumNumberOfWaiters = "1000";
        jdbcConfiguration.poolMaximumOpenTime = "1440";
        jdbcConfiguration.poolMaximumSize = "10";
        jdbcConfiguration.poolMaximumWaitTime = "10";
        jdbcConfiguration.poolMinimumSize = "-1";
        jdbcConfiguration.poolSamplingPeriod = "30";
        jdbcConfiguration.testStatement = "select 1";
    }
}
