/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Jms.java 20821 2011-02-02 16:59:06Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.configuration;

import java.util.ArrayList;
import java.util.List;

/**
 * Create a new Jms object.
 * @author skabore
 */
public class Jms {

    /**
     * The port number.
     */
    private String port;

    /**
     * The list of jms queues.
     */
    private List<String> queues;

    /**
     * The list of jms topics.
     */
    private List<String> topics;

    /**
     * Default constructor.
     */
    public Jms() {
        this.queues = new ArrayList<String>();
        this.topics = new ArrayList<String>();
    }

    /**
     * @return port.
     */
    public String getPort() {
        return this.port;
    }

    /**
     * Set the port number.
     * @param port the new port number
     */
    public void setPort(final String port) {
        this.port = port;
    }

    /**
     * @return queues.
     */
    public List<String> getQueues() {
        return this.queues;
    }

    /**
     * Set the queues list.
     * @param queues the new queues list
     */
    public void setQueues(final List<String> queues) {
        this.queues = queues;
    }

    /**
     * @return topics.
     */
    public List<String> getTopics() {
        return this.topics;
    }

    /**
     * Set the topics list.
     * @param topics the new topics list
     */
    public void setTopics(final List<String> topics) {
        this.topics = topics;
    }

    /**
     * Add a new queue to the list of queues.
     * @param queue the queue to add
     */
    public void addQueues(final String queue) {
        if (!this.queues.contains(queue)) {
            this.queues.add(queue);
        }
    }

    /**
     * Remove a queue from the list of queues.
     * @param queue the queue to remove
     */
    public void removeQueues(final String queue) {
        this.queues.remove(queue);
    }

    /**
     * Add a new topic to the list of topics.
     * @param topic the topic to add
     */
    public void addTopics(final String topic) {
        if (!this.topics.contains(topic)) {
            this.topics.add(topic);
        }
    }

    /**
     * Remove a topic from the list of topics.
     * @param topic the topic to remove
     */
    public void removeTopics(final String topic) {
        this.topics.remove(topic);
    }
}
