/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Utils.java 20821 2011-02-02 16:59:06Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.configurator;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.Collections;
import java.util.Hashtable;
import java.util.List;
import java.util.Map;
import java.util.Properties;

import org.ow2.jonas.autostart.utility.Output;

/**
 * Miscellaneous utilities methods.
 * @author Guillaume Sauthier
 */
public class Utils {
    /**
     * Private empty constructor for Utility class.
     */
    private Utils() {
    }

    /**
     * Convert a properties into an equivalent Map&lt;String, String>.
     * @param properties instance to be converted
     * @return an equivalent typed Map
     */
    @SuppressWarnings("unchecked")
    public static Map<String, String> asMap(final Properties properties) {
        Map<String, String> map = new Hashtable<String, String>();
        if (properties != null) {
            List<String> names = (List<String>) Collections.list(properties.propertyNames());
            for (String name : names) {
                map.put(name, properties.getProperty(name));
            }
        }
        return map;
    }

    /**
     * This method try to fix list string with commas inside.
     * @param value The string to fix.
     * @return The fixed string.
     */
    public static String cleanupCommaSeparatedValue(final String value) {
        String ret = value;
        while (ret.contains(",,")) {
            // Remove duplicated commas
            ret = ret.replaceAll(",,", ",");
        }

        // Trim starting and ending commas (if any)
        if (ret.charAt(0) == ',') {
            ret = ret.substring(1);
        }
        if (ret.charAt(ret.length() - 1) == ',') {
            ret = ret.substring(0, ret.length() - 1);
        }

        return ret;
    }

    /**
     * Returns <tt>true</tt> is the given path denotes an existing directory.
     * @param path file's path
     * @param output stream
     * @return <tt>true</tt> is the given path denotes an existing directory.
     */
    public static boolean isDirectory(final String path, final Output output) {
        File file = new File(path);
        boolean exists = file.isDirectory();
        if (!exists) {
        }
        return exists;
    }

    /**
     * Returns <tt>true</tt> is the given path denotes an existing file (not
     * directory).
     * @param path file's path
     * @param output stream
     * @return <tt>true</tt> is the given path denotes an existing file (not
     *         directory).
     */
    public static boolean isFile(final String path, final Output output) {
        File file = new File(path);
        boolean exists = file.isFile();
        if (!exists) {
        }
        return exists;
    }

    /**
     * This method is used to open a properties file and load it into a
     * properties object resource.
     * @param path the path of the properties file to load
     * @return the Properties Object
     */
    public static boolean loadProperties(final File path, final Properties properties, final Output output) {
        FileInputStream stream = null;
        try {
            stream = new FileInputStream(path);
            return loadProperties(stream, properties, output);
        } catch (FileNotFoundException e) {
            return false;
        }
    }

    /**
     * This method is used to open a properties file and load it into a
     * properties object resource.
     * @param stream source of the Properties
     * @return the Properties Object
     */
    public static boolean loadProperties(final InputStream stream, final Properties properties, final Output output) {
        try {
            properties.load(stream);
        } catch (IOException e) {
            return false;
        } finally {
            if (stream != null) {
                try {
                    stream.close();
                } catch (IOException e) {
                    // Ignored
                }
            }
        }
        return true;
    }
}
